import dictabase
from flask import current_app, _app_ctx_stack

global worker
dictabase.RegisterDBURI()


class Dictabase:
    def __init__(self, app=None):
        self.app = app
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        pass

    def teardown(self, exception):
        pass

    def FindAll(self, *args, **kwargs):
        return dictabase.FindAll(*args, **kwargs)

    def FindOne(self, *args, **kwargs):
        return dictabase.FindOne(*args, **kwargs)

    def New(self, *args, **kwargs):
        return dictabase.New(*args, **kwargs)

    def Delete(self, *args, **kwargs):
        return dictabase.Delete(*args, **kwargs)

    def Drop(self, *args, **kwargs):
        return dictabase.Drop(*args, **kwargs)


class BaseTable(dictabase.BaseTable):
    pass



from setuptools import setup
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

packages = ['flask_dictabase']

setup(
    name="flask_dictabase",

    version="0.0.2",

    packages=packages,
    install_requires=[
        'flask',
        'dictabase',
    ],

    author="Grant miller",
    author_email="grant@grant-miller.com",
    description="A dict() like interface to your database.",
    long_description="A dict() like interface to your database.",
    license="PSF",
    keywords="grant miller flask database",
    url="https://github.com/GrantGMiller/flask_dictabase",  # project home page, if any
    project_urls={
        "Source Code": "https://github.com/GrantGMiller/flask_dictabase",
    }

)
